==> manydhcp2.5.2.tar.bz2: manydhcp/addresses/wakeonlan.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  if(!isset($title)) $title = $TEXT['log-addr9'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}
  if(empty($_GET['ip_id'])) {puterror($result2['skin'],$TEXT['error-addr21']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ip_id'])>255) {puterror($result2['skin'],$TEXT['error-addr22']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ip_id'] = rep($_GET['ip_id']);
  $delimiter = ".";

  $query_body = "SELECT ip_addr, hw FROM tbl_ip WHERE ip_id = ".$_GET['ip_id']." LIMIT 1";
   $result_body = mysql_query($query_body);
     if(!$result_body) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows2 = mysql_num_rows($result_body);
       if($result_rows2 > 0)
        {
         $result_body_addr = mysql_fetch_array($result_body);
          $addr = explode($delimiter,$result_body_addr['ip_addr'],4);
           $oct1 = substr($addr['0'],0,1);
            if($oct1 == '0')
             { 
              $oct_res1 = substr($addr['0'],1,1);
               if($oct_res1 == '0') 
                {
                 $oct_result1 = substr($addr['0'],2,3);
                } else $oct_result1 = substr($addr['0'],1,3);
              } else $oct_result1 = $addr['0'];
           $oct2 = substr($addr['1'],0,1);
            if($oct2 == '0')
             { 
              $oct_res2 = substr($addr['1'],1,1);
               if($oct_res2 == '0') 
                {
                $oct_result2 = substr($addr['1'],2,3);
                } else $oct_result2 = substr($addr['1'],1,3);
              } else $oct_result2 = $addr['1'];
           $oct3 = substr($addr['2'],0,1);
            if($oct3 == '0')
             { 
             $oct_res3 = substr($addr['2'],1,1);
               if($oct_res3 == '0') 
                {
                $oct_result3 = substr($addr['2'],2,3);
                } else $oct_result3 = substr($addr['2'],1,3);
              } else $oct_result3 = $addr['2'];
           $oct4 = substr($addr['3'],0,1);
            if($oct4 == '0')
             { 
             $oct_res4 = substr($addr['3'],1,1);
              if($oct_res4 == '0') 
               {
               $oct_result4 = substr($addr['3'],2,3);
               } else $oct_result4 = substr($addr['3'],1,3);
             } else $oct_result4 = $addr['3'];
        $ip_addres = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;
        $mac = substr(chunk_split($result_body_addr['hw'],2,":"),0,-1);
        $addres = "255.255.255.255";
        $socket_number = "9";
       flush();
       WakeOnLan($addres,$mac,$socket_number);
       }
       else {puterror($result2['skin'],$TEXT['error-addr19']); require_once "../utils/bottom_adm.php"; exit();}

  //*************************************
  //Информация для лога
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-addr9'];
  $what = $ip_addres."&nbsp;(".$mac.", UDP port: ".$socket_number.")";
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************
  $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
   if(mysql_query($query2))
    {
    echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
          </head></html>";
    } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/addresses/wakeonlan.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['log-addr9'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}
  if(empty($_GET['ip_id'])) {puterror($result2['skin'],$TEXT['error-addr21']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ip_id'])>255) {puterror($result2['skin'],$TEXT['error-addr22']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ip_id'] = rep($_GET['ip_id']);
  $delimiter = ".";

  $query_body = "SELECT ip_addr, hw FROM tbl_ip WHERE ip_id = ".$_GET['ip_id']." LIMIT 1";
   $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows2 = mysqli_num_rows($result_body);
       if($result_rows2 > 0)
        {
         $result_body_addr = mysqli_fetch_array($result_body,MYSQLI_ASSOC);
          $addr = explode($delimiter,$result_body_addr['ip_addr'],4);
           $oct1 = substr($addr['0'],0,1);
            if($oct1 == '0')
             { 
              $oct_res1 = substr($addr['0'],1,1);
               if($oct_res1 == '0') 
                {
                 $oct_result1 = substr($addr['0'],2,3);
                } else {$oct_result1 = substr($addr['0'],1,3);}
              } else {$oct_result1 = $addr['0'];}
           $oct2 = substr($addr['1'],0,1);
            if($oct2 == '0')
             { 
              $oct_res2 = substr($addr['1'],1,1);
               if($oct_res2 == '0') 
                {
                $oct_result2 = substr($addr['1'],2,3);
                } else {$oct_result2 = substr($addr['1'],1,3);}
              } else {$oct_result2 = $addr['1'];}
           $oct3 = substr($addr['2'],0,1);
            if($oct3 == '0')
             { 
             $oct_res3 = substr($addr['2'],1,1);
               if($oct_res3 == '0') 
                {
                $oct_result3 = substr($addr['2'],2,3);
                } else {$oct_result3 = substr($addr['2'],1,3);}
              } else {$oct_result3 = $addr['2'];}
           $oct4 = substr($addr['3'],0,1);
            if($oct4 == '0')
             { 
             $oct_res4 = substr($addr['3'],1,1);
              if($oct_res4 == '0') 
               {
               $oct_result4 = substr($addr['3'],2,3);
               } else {$oct_result4 = substr($addr['3'],1,3);}
             } else {$oct_result4 = $addr['3'];}
        $ip_addres = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;
        $mac = substr(chunk_split($result_body_addr['hw'],2,":"),0,-1);
        $addres = "255.255.255.255";
        $socket_number = "9";
       flush();
       WakeOnLan($addres,$mac,$socket_number);
       }
       else {puterror($result2['skin'],$TEXT['error-addr19']); require_once "../utils/bottom_adm.php"; exit();}

  //*************************************
  //Информация для лога
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-addr9'];
  $what = $ip_addres."&nbsp;(".$mac.", UDP port: ".$socket_number.")";
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************
  $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
   if(mysqli_query($dbcnx,$query2))
    {
    echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
          </head></html>";
    } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>
